about summary refs log tree commit homepage
diff options
context:
space:
mode:
authorEric Wong <e@80x24.org>2017-02-09 01:37:03 +0000
committerEric Wong <e@80x24.org>2017-02-09 01:37:03 +0000
commitd9563ea5516e8e786debf223e10ec11695aee9d7 (patch)
treea0842b1ee0953bc8e65d21d5d96432f41973adb7
parentfb9ed5324ec7de9420956840ba9a6585b81e8231 (diff)
downloadpublic-inbox-d9563ea5516e8e786debf223e10ec11695aee9d7.tar.gz
We'll still be keeping "repobrowse" for the public API
for use with .psgi files, but shortening the name means
less typing and we may have command-line tools, too.
-rw-r--r--MANIFEST36
-rw-r--r--lib/PublicInbox/RepoBase.pm (renamed from lib/PublicInbox/RepobrowseBase.pm)4
-rw-r--r--lib/PublicInbox/RepoConfig.pm (renamed from lib/PublicInbox/RepobrowseConfig.pm)2
-rw-r--r--lib/PublicInbox/RepoGit.pm (renamed from lib/PublicInbox/RepobrowseGit.pm)4
-rw-r--r--lib/PublicInbox/RepoGitAtom.pm (renamed from lib/PublicInbox/RepobrowseGitAtom.pm)6
-rw-r--r--lib/PublicInbox/RepoGitBlob.pm (renamed from lib/PublicInbox/RepobrowseGitBlob.pm)6
-rw-r--r--lib/PublicInbox/RepoGitCommit.pm (renamed from lib/PublicInbox/RepobrowseGitCommit.pm)12
-rw-r--r--lib/PublicInbox/RepoGitDiff.pm (renamed from lib/PublicInbox/RepobrowseGitDiff.pm)8
-rw-r--r--lib/PublicInbox/RepoGitDiffCommon.pm (renamed from lib/PublicInbox/RepobrowseGitDiffCommon.pm)4
-rw-r--r--lib/PublicInbox/RepoGitFallback.pm (renamed from lib/PublicInbox/RepobrowseGitFallback.pm)6
-rw-r--r--lib/PublicInbox/RepoGitLog.pm (renamed from lib/PublicInbox/RepobrowseGitLog.pm)8
-rw-r--r--lib/PublicInbox/RepoGitPatch.pm (renamed from lib/PublicInbox/RepobrowseGitPatch.pm)6
-rw-r--r--lib/PublicInbox/RepoGitPlain.pm (renamed from lib/PublicInbox/RepobrowseGitPlain.pm)8
-rw-r--r--lib/PublicInbox/RepoGitQuery.pm (renamed from lib/PublicInbox/RepobrowseGitQuery.pm)2
-rw-r--r--lib/PublicInbox/RepoGitSnapshot.pm (renamed from lib/PublicInbox/RepobrowseGitSnapshot.pm)6
-rw-r--r--lib/PublicInbox/RepoGitSummary.pm (renamed from lib/PublicInbox/RepobrowseGitSummary.pm)4
-rw-r--r--lib/PublicInbox/RepoGitTag.pm (renamed from lib/PublicInbox/RepobrowseGitTag.pm)6
-rw-r--r--lib/PublicInbox/RepoGitTree.pm (renamed from lib/PublicInbox/RepobrowseGitTree.pm)6
-rw-r--r--lib/PublicInbox/RepoRoot.pm (renamed from lib/PublicInbox/RepobrowseRoot.pm)4
-rw-r--r--lib/PublicInbox/Repobrowse.pm14
-rw-r--r--t/repobrowse_git.t2
21 files changed, 77 insertions, 77 deletions
diff --git a/MANIFEST b/MANIFEST
index d0223c65..a59d9dcc 100644
--- a/MANIFEST
+++ b/MANIFEST
@@ -80,27 +80,27 @@ lib/PublicInbox/NewsWWW.pm
 lib/PublicInbox/ParentPipe.pm
 lib/PublicInbox/ProcessPipe.pm
 lib/PublicInbox/Qspawn.pm
+lib/PublicInbox/RepoBase.pm
+lib/PublicInbox/RepoConfig.pm
+lib/PublicInbox/RepoGit.pm
+lib/PublicInbox/RepoGitAtom.pm
+lib/PublicInbox/RepoGitBlob.pm
+lib/PublicInbox/RepoGitCommit.pm
+lib/PublicInbox/RepoGitDiff.pm
+lib/PublicInbox/RepoGitDiffCommon.pm
+lib/PublicInbox/RepoGitFallback.pm
+lib/PublicInbox/RepoGitLog.pm
+lib/PublicInbox/RepoGitPatch.pm
+lib/PublicInbox/RepoGitPlain.pm
+lib/PublicInbox/RepoGitQuery.pm
 lib/PublicInbox/RepoGitSearch.pm
 lib/PublicInbox/RepoGitSearchIdx.pm
+lib/PublicInbox/RepoGitSnapshot.pm
+lib/PublicInbox/RepoGitSummary.pm
+lib/PublicInbox/RepoGitTag.pm
+lib/PublicInbox/RepoGitTree.pm
+lib/PublicInbox/RepoRoot.pm
 lib/PublicInbox/Repobrowse.pm
-lib/PublicInbox/RepobrowseBase.pm
-lib/PublicInbox/RepobrowseConfig.pm
-lib/PublicInbox/RepobrowseGit.pm
-lib/PublicInbox/RepobrowseGitAtom.pm
-lib/PublicInbox/RepobrowseGitBlob.pm
-lib/PublicInbox/RepobrowseGitCommit.pm
-lib/PublicInbox/RepobrowseGitDiff.pm
-lib/PublicInbox/RepobrowseGitDiffCommon.pm
-lib/PublicInbox/RepobrowseGitFallback.pm
-lib/PublicInbox/RepobrowseGitLog.pm
-lib/PublicInbox/RepobrowseGitPatch.pm
-lib/PublicInbox/RepobrowseGitPlain.pm
-lib/PublicInbox/RepobrowseGitQuery.pm
-lib/PublicInbox/RepobrowseGitSnapshot.pm
-lib/PublicInbox/RepobrowseGitSummary.pm
-lib/PublicInbox/RepobrowseGitTag.pm
-lib/PublicInbox/RepobrowseGitTree.pm
-lib/PublicInbox/RepobrowseRoot.pm
 lib/PublicInbox/SaPlugin/ListMirror.pm
 lib/PublicInbox/Search.pm
 lib/PublicInbox/SearchIdx.pm
diff --git a/lib/PublicInbox/RepobrowseBase.pm b/lib/PublicInbox/RepoBase.pm
index 44f422df..e60677d6 100644
--- a/lib/PublicInbox/RepobrowseBase.pm
+++ b/lib/PublicInbox/RepoBase.pm
@@ -1,9 +1,9 @@
 # Copyright (C) 2015 all contributors <meta@public-inbox.org>
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
-package PublicInbox::RepobrowseBase;
+package PublicInbox::RepoBase;
 use strict;
 use warnings;
-require PublicInbox::RepobrowseGitQuery;
+require PublicInbox::RepoGitQuery;
 use PublicInbox::Hval;
 our %MIME_TYPE_WHITELIST = ('application/pdf' => 1);
 
diff --git a/lib/PublicInbox/RepobrowseConfig.pm b/lib/PublicInbox/RepoConfig.pm
index a08c6cec..32346852 100644
--- a/lib/PublicInbox/RepobrowseConfig.pm
+++ b/lib/PublicInbox/RepoConfig.pm
@@ -1,6 +1,6 @@
 # Copyright (C) 2015 all contributors <meta@public-inbox.org>
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
-package PublicInbox::RepobrowseConfig;
+package PublicInbox::RepoConfig;
 use strict;
 use warnings;
 use PublicInbox::Inbox;
diff --git a/lib/PublicInbox/RepobrowseGitAtom.pm b/lib/PublicInbox/RepoGitAtom.pm
index 65b723c4..a9f40126 100644
--- a/lib/PublicInbox/RepobrowseGitAtom.pm
+++ b/lib/PublicInbox/RepoGitAtom.pm
@@ -2,11 +2,11 @@
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
 
 # show log as an Atom feed
-package PublicInbox::RepobrowseGitAtom;
+package PublicInbox::RepoGitAtom;
 use strict;
 use warnings;
 use PublicInbox::Hval qw(utf8_html);
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use PublicInbox::Qspawn;
 
 use constant DATEFMT => '%Y-%m-%dT%H:%M:%SZ';
@@ -139,7 +139,7 @@ sub call_git_atom {
 
         my $git = $repo_info->{git};
         my $env = $req->{env};
-        my $q =$req->{'q'} = PublicInbox::RepobrowseGitQuery->new($env);
+        my $q =$req->{'q'} = PublicInbox::RepoGitQuery->new($env);
         my $h = $q->{h};
         my $read_log = sub {
                 my $cmd = $git->cmd(qw(log --no-notes --no-color
diff --git a/lib/PublicInbox/RepobrowseGitBlob.pm b/lib/PublicInbox/RepoGitBlob.pm
index a11c457c..586b4acc 100644
--- a/lib/PublicInbox/RepobrowseGitBlob.pm
+++ b/lib/PublicInbox/RepoGitBlob.pm
@@ -2,17 +2,17 @@
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
 
 # Show a blob as-is
-package PublicInbox::RepobrowseGitBlob;
+package PublicInbox::RepoGitBlob;
 use strict;
 use warnings;
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use base qw(Exporter);
 our @EXPORT = qw(git_blob_mime_type git_blob_stream_response);
 
 sub call_git_blob {
         my ($self, $req) = @_;
         my $git = $req->{repo_info}->{git};
-        my $q = PublicInbox::RepobrowseGitQuery->new($req->{env});
+        my $q = PublicInbox::RepoGitQuery->new($req->{env});
         my $id = $q->{id};
         $id eq '' and $id = 'HEAD';
         $id .= ":$req->{expath}";
diff --git a/lib/PublicInbox/RepobrowseGitDiff.pm b/lib/PublicInbox/RepoGitDiff.pm
index e2b7179f..bb71e738 100644
--- a/lib/PublicInbox/RepobrowseGitDiff.pm
+++ b/lib/PublicInbox/RepoGitDiff.pm
@@ -6,12 +6,12 @@
 #
 # We probably will not link to this outright because it's expensive,
 # but exists to preserve URL compatibility with cgit.
-package PublicInbox::RepobrowseGitDiff;
+package PublicInbox::RepoGitDiff;
 use strict;
 use warnings;
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use PublicInbox::Hval qw(utf8_html);
-use PublicInbox::RepobrowseGitDiffCommon;
+use PublicInbox::RepoGitDiffCommon;
 use PublicInbox::Qspawn;
 
 sub git_diff_sed ($$) {
@@ -35,7 +35,7 @@ sub git_diff_sed ($$) {
 sub call_git_diff {
         my ($self, $req) = @_;
         my $env = $req->{env};
-        my $q = PublicInbox::RepobrowseGitQuery->new($env);
+        my $q = PublicInbox::RepoGitQuery->new($env);
         my $id = $q->{id};
         my $id2 = $q->{id2};
 
diff --git a/lib/PublicInbox/RepobrowseGitDiffCommon.pm b/lib/PublicInbox/RepoGitDiffCommon.pm
index 968ca7a7..0604f9dd 100644
--- a/lib/PublicInbox/RepobrowseGitDiffCommon.pm
+++ b/lib/PublicInbox/RepoGitDiffCommon.pm
@@ -2,10 +2,10 @@
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
 
 # common git diff-related code
-package PublicInbox::RepobrowseGitDiffCommon;
+package PublicInbox::RepoGitDiffCommon;
 use strict;
 use warnings;
-use PublicInbox::RepobrowseGit qw/git_unquote git_commit_title/;
+use PublicInbox::RepoGit qw/git_unquote git_commit_title/;
 use PublicInbox::Hval qw/utf8_html to_attr/;
 use base qw/Exporter/;
 our @EXPORT = qw/git_diff_sed_init git_diff_sed_close git_diff_sed_run
diff --git a/lib/PublicInbox/RepobrowseGitFallback.pm b/lib/PublicInbox/RepoGitFallback.pm
index 38640139..5ce469be 100644
--- a/lib/PublicInbox/RepobrowseGitFallback.pm
+++ b/lib/PublicInbox/RepoGitFallback.pm
@@ -3,13 +3,13 @@
 
 # when no endpoints match, fallback to this and serve a static file
 # This can serve Smart HTTP in the future.
-package PublicInbox::RepobrowseGitFallback;
+package PublicInbox::RepoGitFallback;
 use strict;
 use warnings;
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use PublicInbox::GitHTTPBackend;
 
-# overrides PublicInbox::RepobrowseBase::call
+# overrides PublicInbox::RepoBase::call
 sub call {
         my ($self, undef, $req) = @_;
         my $expath = $req->{expath};
diff --git a/lib/PublicInbox/RepobrowseGitLog.pm b/lib/PublicInbox/RepoGitLog.pm
index 85593cb8..9cfa526e 100644
--- a/lib/PublicInbox/RepobrowseGitLog.pm
+++ b/lib/PublicInbox/RepoGitLog.pm
@@ -2,12 +2,12 @@
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
 
 # show the log view
-package PublicInbox::RepobrowseGitLog;
+package PublicInbox::RepoGitLog;
 use strict;
 use warnings;
 use PublicInbox::Hval qw(utf8_html);
-use base qw(PublicInbox::RepobrowseBase);
-use PublicInbox::RepobrowseGit qw(git_dec_links git_commit_title);
+use base qw(PublicInbox::RepoBase);
+use PublicInbox::RepoGit qw(git_dec_links git_commit_title);
 use PublicInbox::Qspawn;
 # cannot rely on --date=format-local:... yet, it is too new (September 2015)
 use constant STATES => qw(h p D ai an s b);
@@ -126,7 +126,7 @@ sub call_git_log {
         $max = int($max);
         $max = 50 if $max == 0;
         my $env = $req->{env};
-        my $q = $req->{'q'} = PublicInbox::RepobrowseGitQuery->new($env);
+        my $q = $req->{'q'} = PublicInbox::RepoGitQuery->new($env);
         my $h = $q->{h};
         $h eq '' and $h = 'HEAD';
         my $git = $repo_info->{git};
diff --git a/lib/PublicInbox/RepobrowseGitPatch.pm b/lib/PublicInbox/RepoGitPatch.pm
index 5ae768e8..e9227b6f 100644
--- a/lib/PublicInbox/RepobrowseGitPatch.pm
+++ b/lib/PublicInbox/RepoGitPatch.pm
@@ -3,10 +3,10 @@
 
 # shows the /patch/ endpoint for git repositories
 # usage: /repo.git/patch?id=COMMIT_ID
-package PublicInbox::RepobrowseGitPatch;
+package PublicInbox::RepoGitPatch;
 use strict;
 use warnings;
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use PublicInbox::Qspawn;
 
 # try to be educational and show the command-line used in the signature
@@ -17,7 +17,7 @@ sub call_git_patch {
         my ($self, $req) = @_;
         my $git = $req->{repo_info}->{git};
         my $env = $req->{env};
-        my $q = PublicInbox::RepobrowseGitQuery->new($env);
+        my $q = PublicInbox::RepoGitQuery->new($env);
         my $id = $q->{id};
         $id =~ /\A[\w-]+([~\^][~\^\d])*\z/ or $id = 'HEAD';
 
diff --git a/lib/PublicInbox/RepobrowseGitPlain.pm b/lib/PublicInbox/RepoGitPlain.pm
index 24cc70b0..2ba24e08 100644
--- a/lib/PublicInbox/RepobrowseGitPlain.pm
+++ b/lib/PublicInbox/RepoGitPlain.pm
@@ -1,17 +1,17 @@
 # Copyright (C) 2015-2016 all contributors <meta@public-inbox.org>
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
-package PublicInbox::RepobrowseGitPlain;
+package PublicInbox::RepoGitPlain;
 use strict;
 use warnings;
-use base qw(PublicInbox::RepobrowseBase);
-use PublicInbox::RepobrowseGitBlob;
+use base qw(PublicInbox::RepoBase);
+use PublicInbox::RepoGitBlob;
 use PublicInbox::Hval qw(utf8_html);
 use PublicInbox::Qspawn;
 
 sub call_git_plain {
         my ($self, $req) = @_;
         my $git = $req->{repo_info}->{git};
-        my $q = PublicInbox::RepobrowseGitQuery->new($req->{env});
+        my $q = PublicInbox::RepoGitQuery->new($req->{env});
         my $id = $q->{id};
         $id eq '' and $id = 'HEAD';
         $id .= ":$req->{expath}";
diff --git a/lib/PublicInbox/RepobrowseGitQuery.pm b/lib/PublicInbox/RepoGitQuery.pm
index 1140f6fa..638a1316 100644
--- a/lib/PublicInbox/RepobrowseGitQuery.pm
+++ b/lib/PublicInbox/RepoGitQuery.pm
@@ -2,7 +2,7 @@
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
 
 # query parameter management for repobrowse
-package PublicInbox::RepobrowseGitQuery;
+package PublicInbox::RepoGitQuery;
 use strict;
 use warnings;
 use PublicInbox::Hval;
diff --git a/lib/PublicInbox/RepobrowseGitSummary.pm b/lib/PublicInbox/RepoGitSummary.pm
index e7739ecd..e9e1458b 100644
--- a/lib/PublicInbox/RepobrowseGitSummary.pm
+++ b/lib/PublicInbox/RepoGitSummary.pm
@@ -2,11 +2,11 @@
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
 
 # The main summary/landing page of a git repository viewer
-package PublicInbox::RepobrowseGitSummary;
+package PublicInbox::RepoGitSummary;
 use strict;
 use warnings;
 use PublicInbox::Hval qw(utf8_html);
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use PublicInbox::Qspawn;
 
 sub call_git_summary {
diff --git a/lib/PublicInbox/RepobrowseGitTag.pm b/lib/PublicInbox/RepoGitTag.pm
index 1d26eab0..96835b2c 100644
--- a/lib/PublicInbox/RepobrowseGitTag.pm
+++ b/lib/PublicInbox/RepoGitTag.pm
@@ -2,10 +2,10 @@
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
 
 # shows the /tag/ endpoint for git repositories
-package PublicInbox::RepobrowseGitTag;
+package PublicInbox::RepoGitTag;
 use strict;
 use warnings;
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use POSIX qw(strftime);
 use PublicInbox::Hval qw(utf8_html);
 use PublicInbox::Qspawn;
@@ -19,7 +19,7 @@ my %cmd_map = ( # type => action
 sub call_git_tag {
         my ($self, $req) = @_;
 
-        my $q = PublicInbox::RepobrowseGitQuery->new($req->{env});
+        my $q = PublicInbox::RepoGitQuery->new($req->{env});
         my $h = $q->{h};
         $h eq '' and return git_tag_list($self, $req);
         sub {
diff --git a/lib/PublicInbox/RepobrowseGitTree.pm b/lib/PublicInbox/RepoGitTree.pm
index c242fd1a..4a68cf69 100644
--- a/lib/PublicInbox/RepobrowseGitTree.pm
+++ b/lib/PublicInbox/RepoGitTree.pm
@@ -1,9 +1,9 @@
 # Copyright (C) 2015 all contributors <meta@public-inbox.org>
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
-package PublicInbox::RepobrowseGitTree;
+package PublicInbox::RepoGitTree;
 use strict;
 use warnings;
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use PublicInbox::Hval qw(utf8_html);
 use PublicInbox::Qspawn;
 
@@ -21,7 +21,7 @@ sub call_git_tree {
         my ($self, $req) = @_;
         my @extra = @{$req->{extra}};
         my $git = $req->{repo_info}->{git};
-        my $q = PublicInbox::RepobrowseGitQuery->new($req->{env});
+        my $q = PublicInbox::RepoGitQuery->new($req->{env});
         my $id = $q->{id};
         if ($id eq '') {
                 chomp($id = $git->qx(qw(rev-parse --short=10 HEAD)));
diff --git a/lib/PublicInbox/RepobrowseRoot.pm b/lib/PublicInbox/RepoRoot.pm
index fda96437..9ab25b97 100644
--- a/lib/PublicInbox/RepobrowseRoot.pm
+++ b/lib/PublicInbox/RepoRoot.pm
@@ -2,10 +2,10 @@
 # License: AGPL-3.0+ <https://www.gnu.org/licenses/agpl-3.0.txt>
 
 # displays the root '/' where all the projects lie
-package PublicInbox::RepobrowseRoot;
+package PublicInbox::RepoRoot;
 use strict;
 use warnings;
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use PublicInbox::Hval qw(utf8_html);
 
 sub call {
diff --git a/lib/PublicInbox/Repobrowse.pm b/lib/PublicInbox/Repobrowse.pm
index 1050ed50..87e12278 100644
--- a/lib/PublicInbox/Repobrowse.pm
+++ b/lib/PublicInbox/Repobrowse.pm
@@ -21,7 +21,7 @@ package PublicInbox::Repobrowse;
 use strict;
 use warnings;
 use URI::Escape qw(uri_escape_utf8 uri_unescape);
-use PublicInbox::RepobrowseConfig;
+use PublicInbox::RepoConfig;
 
 my %CMD = map { lc($_) => $_ } qw(Log Commit Tree Patch Blob Plain Tag Atom
         Diff Snapshot);
@@ -30,7 +30,7 @@ my %LOADED;
 
 sub new {
         my ($class, $rconfig) = @_;
-        $rconfig ||= PublicInbox::RepobrowseConfig->new;
+        $rconfig ||= PublicInbox::RepoConfig->new;
         bless { rconfig => $rconfig }, $class;
 }
 
@@ -80,8 +80,8 @@ sub no_tslash {
 
 sub root_index {
         my ($self) = @_;
-        my $mod = load_once('PublicInbox::RepobrowseRoot');
-        $mod->new->call($self->{rconfig}); # RepobrowseRoot::call
+        my $mod = load_once('PublicInbox::RepoRoot');
+        $mod->new->call($self->{rconfig}); # RepoRoot::call
 }
 
 sub call {
@@ -97,7 +97,7 @@ sub call {
 
         return $self->root_index($self) unless length($repo_path);
 
-        my $rconfig = $self->{rconfig}; # RepobrowseConfig
+        my $rconfig = $self->{rconfig}; # RepoConfig
         my $repo_info;
         until ($repo_info = $rconfig->lookup($repo_path)) {
                 my $p = shift @extra or last;
@@ -141,14 +141,14 @@ sub call {
         return no_tslash($env) if ($tslash && $NO_TSLASH{$mod});
 
         $req->{tslash} = $tslash;
-        $mod = load_once("PublicInbox::Repobrowse$vcs$mod");
+        $mod = load_once("PublicInbox::Repo$vcs$mod");
         $vcs = load_once("PublicInbox::$vcs");
 
         # $repo_info->{git} ||= PublicInbox::Git->new(...)
         $repo_info->{$vcs_lc} ||= $vcs->new($repo_info->{path});
 
         $req->{expath} = join('/', @extra);
-        my $rv = eval { $mod->new->call($cmd, $req) }; # RepobrowseBase::call
+        my $rv = eval { $mod->new->call($cmd, $req) }; # RepoBase::call
         $rv || r404();
 }
 
diff --git a/t/repobrowse_git.t b/t/repobrowse_git.t
index 6ae7475b..0ac977f3 100644
--- a/t/repobrowse_git.t
+++ b/t/repobrowse_git.t
@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 use Test::More;
-use PublicInbox::RepobrowseGit qw(git_unquote);
+use PublicInbox::RepoGit qw(git_unquote);
 
 is("foo\nbar", git_unquote('"foo\\nbar"'), 'unquoted newline');
 is("ElĂ©anor", git_unquote('"El\\303\\251anor"'), 'unquoted octal');
diff --git a/lib/PublicInbox/RepobrowseGit.pm b/lib/PublicInbox/RepoGit.pm
index eb79e563..f7bf0b9d 100644
--- a/lib/PublicInbox/RepobrowseGit.pm
+++ b/lib/PublicInbox/RepoGit.pm
@@ -1,8 +1,8 @@
 # Copyright (C) 2015 all contributors <meta@public-inbox.org>
 # License: AGPL-3.0+ (https://www.gnu.org/licenses/agpl-3.0.txt)
 
-# common functions used by other RepobrowseGit* modules
-package PublicInbox::RepobrowseGit;
+# common functions used by other RepoGit* modules
+package PublicInbox::RepoGit;
 use strict;
 use warnings;
 use base qw(Exporter);
diff --git a/lib/PublicInbox/RepobrowseGitCommit.pm b/lib/PublicInbox/RepoGitCommit.pm
index 6eadd2e5..e98c3c18 100644
--- a/lib/PublicInbox/RepobrowseGitCommit.pm
+++ b/lib/PublicInbox/RepoGitCommit.pm
@@ -11,13 +11,13 @@
 # punish the common case with extra bytes if somebody uses 'D' or 'P'
 # in filenames.
 
-package PublicInbox::RepobrowseGitCommit;
+package PublicInbox::RepoGitCommit;
 use strict;
 use warnings;
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use PublicInbox::Hval qw(utf8_html to_attr);
-use PublicInbox::RepobrowseGit qw(git_unquote git_commit_title);
-use PublicInbox::RepobrowseGitDiffCommon;
+use PublicInbox::RepoGit qw(git_unquote git_commit_title);
+use PublicInbox::RepoGitDiffCommon;
 use PublicInbox::Qspawn;
 
 use constant GIT_FMT => '--pretty=format:'.join('%n',
@@ -116,10 +116,10 @@ sub git_commit_sed ($$) {
         }
 }
 
-sub call_git_commit { # RepobrowseBase calls this
+sub call_git_commit { # RepoBase calls this
         my ($self, $req) = @_;
         my $env = $req->{env};
-        my $q = PublicInbox::RepobrowseGitQuery->new($env);
+        my $q = PublicInbox::RepoGitQuery->new($env);
         my $id = $q->{id};
         $id eq '' and $id = 'HEAD';
 
diff --git a/lib/PublicInbox/RepobrowseGitSnapshot.pm b/lib/PublicInbox/RepoGitSnapshot.pm
index 450fdad6..e05ad80c 100644
--- a/lib/PublicInbox/RepobrowseGitSnapshot.pm
+++ b/lib/PublicInbox/RepoGitSnapshot.pm
@@ -5,10 +5,10 @@
 # Mainly for compatibility reasons with cgit, I'm unsure if
 # showing this in a repository viewer is a good idea.
 
-package PublicInbox::RepobrowseGitSnapshot;
+package PublicInbox::RepoGitSnapshot;
 use strict;
 use warnings;
-use base qw(PublicInbox::RepobrowseBase);
+use base qw(PublicInbox::RepoBase);
 use PublicInbox::Git;
 use PublicInbox::Qspawn;
 our $SUFFIX;
@@ -33,7 +33,7 @@ our %FMT_TYPES = (
         'zip' => 'application/x-zip',
 );
 
-sub call_git_snapshot ($$) { # invoked by PublicInbox::RepobrowseBase::call
+sub call_git_snapshot ($$) { # invoked by PublicInbox::RepoBase::call
         my ($self, $req) = @_;
 
         my @extra = @{$req->{extra}};